@@ -1,8 +1,9 @@
-use crate::TabContent;
 use mpd::Subsystem;
 use serde::{Deserialize, Serialize};
 use strum_macros::EnumIter;
 
+pub use crate::model::TabContent;
+
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Hash, EnumIter, Serialize, Deserialize)]
 pub enum Context {
     Global,
