@@ -1,4 +1,4 @@
-use crate::{model::AppHandle, util::ui_util::StatefulTable, MPDConnection};
+use crate::{util::ui_util::StatefulTable, App};
 use mpd::Playlist;
 
 #[derive(Debug, Clone)]
@@ -20,7 +20,9 @@ impl PlaylistsModel {
     }
 }
 
-pub fn play(app: &AppHandle, connection: &mut MPDConnection) {
+pub fn play(app: &App) {
+    let mut connection = app.connection();
+
     connection
         .clear()
         .ok()
@@ -30,8 +32,8 @@ pub fn play(app: &AppHandle, connection: &mut MPDConnection) {
         .and_then(|_| connection.play().ok());
 }
 
-pub fn update(app: &AppHandle, connection: &mut MPDConnection) {
-    let playlists = connection.playlists();
+pub fn update(app: &App) {
+    let playlists = app.connection().playlists();
 
     app.model().playlists.items =
         StatefulTable::with_items(playlists.unwrap_or_else(|_| Vec::new()));
